package history

type AlbumType struct {
	Value    *string  `xml:"value,attr,omitempty"`
	Track    *float64 `xml:"TRACK,attr,omitempty"`
	Title    *string  `xml:"TITLE,attr,omitempty"`
	OfTracks *float64 `xml:"OF_TRACKS,attr,omitempty"`
}

type CueV2Type struct {
	Value      *string  `xml:"value,attr,omitempty"`
	Name       *string  `xml:"NAME,attr,omitempty"`
	DisplOrder *float64 `xml:"DISPL_ORDER,attr,omitempty"`
	Type       *float64 `xml:"TYPE,attr,omitempty"`
	Start      *float64 `xml:"START,attr,omitempty"`
	Len        *float64 `xml:"LEN,attr,omitempty"`
	Repeats    *float64 `xml:"REPEATS,attr,omitempty"`
	Hotcue     *float64 `xml:"HOTCUE,attr,omitempty"`
}

type ExtendedDataType struct {
	Value        *string  `xml:"value,attr,omitempty"`
	Deck         *float64 `xml:"DECK,attr,omitempty"`
	Duration     *float64 `xml:"DURATION,attr,omitempty"`
	ExtendedType *string  `xml:"EXTENDEDTYPE,attr,omitempty"`
	PlayedPublic *float64 `xml:"PLAYEDPUBLIC,attr,omitempty"`
	StartDate    *float64 `xml:"STARTDATE,attr,omitempty"`
	StartTime    *float64 `xml:"STARTTIME,attr,omitempty"`
}

type HeadType struct {
	Value   *string `xml:"value,attr,omitempty"`
	Company *string `xml:"COMPANY,attr,omitempty"`
	Program *string `xml:"PROGRAM,attr,omitempty"`
}

type InfoType struct {
	Value         *string  `xml:"value,attr,omitempty"`
	Bitrate       *float64 `xml:"BITRATE,attr,omitempty"`
	Genre         *string  `xml:"GENRE,attr,omitempty"`
	Label         *string  `xml:"LABEL,attr,omitempty"`
	CoverArtID    *string  `xml:"COVERARTID,attr,omitempty"`
	Key           *string  `xml:"KEY,attr,omitempty"`
	PlayCount     *float64 `xml:"PLAYCOUNT,attr,omitempty"`
	PlayTime      *float64 `xml:"PLAYTIME,attr,omitempty"`
	PlayTimeFloat *float64 `xml:"PLAYTIME_FLOAT,attr,omitempty"`
	ImportDate    *string  `xml:"IMPORT_DATE,attr,omitempty"`
	LastPlayed    *string  `xml:"LAST_PLAYED,attr,omitempty"`
	ReleaseDate   *string  `xml:"RELEASE_DATE,attr,omitempty"`
	Flags         *float64 `xml:"FLAGS,attr,omitempty"`
	FileSize      *float64 `xml:"FILESIZE,attr,omitempty"`
	Comment       *string  `xml:"COMMENT,attr,omitempty"`
	Ranking       *float64 `xml:"RANKING,attr,omitempty"`
	KeyLyrics     *string  `xml:"KEY_LYRICS,attr,omitempty"`
	Remixer       *string  `xml:"REMIXER,attr,omitempty"`
	Producer      *string  `xml:"PRODUCER,attr,omitempty"`
	Color         *float64 `xml:"COLOR,attr,omitempty"`
}

type LocationType struct {
	Value    *string `xml:"value,attr,omitempty"`
	Dir      *string `xml:"DIR,attr,omitempty"`
	File     *string `xml:"FILE,attr,omitempty"`
	Volume   *string `xml:"VOLUME,attr,omitempty"`
	VolumeID *string `xml:"VOLUMEID,attr,omitempty"`
}

type LoopInfoType struct {
	Value             *string  `xml:"value,attr,omitempty"`
	OriginalTitle     *string  `xml:"ORIGINAL_TITLE,attr,omitempty"`
	OriginalTrackID   *string  `xml:"ORIGINAL_TRACKID,attr,omitempty"`
	OriginalLoopSize  *float64 `xml:"ORIGINAL_LOOP_SIZE,attr,omitempty"`
	OriginalLoopStart *float64 `xml:"ORIGINAL_LOOP_START,attr,omitempty"`
	SampleTypeInfo    *float64 `xml:"SAMPLE_TYPE_INFO,attr,omitempty"`
}

type LoudnessType struct {
	Value       *string  `xml:"value,attr,omitempty"`
	PeakDB      *float64 `xml:"PEAK_DB,attr,omitempty"`
	PerceivedDB *float64 `xml:"PERCEIVED_DB,attr,omitempty"`
	AnalyzedDB  *float64 `xml:"ANALYZED_DB,attr,omitempty"`
}

type ModificationInfoType struct {
	Value      *string `xml:"value,attr,omitempty"`
	AuthorType *string `xml:"AUTHOR_TYPE,attr,omitempty"`
}

type MusicalKeyType struct {
	Value          *string  `xml:"value,attr,omitempty"`
	ValueAttribute *float64 `xml:"VALUE,attr,omitempty"`
}

type PrimaryKeyType struct {
	Value *string `xml:"value,attr,omitempty"`
	Type  *string `xml:"TYPE,attr,omitempty"`
	Key   *string `xml:"KEY,attr,omitempty"`
}

type SetsType struct {
	Value   *string  `xml:"value,attr,omitempty"`
	Entries *float64 `xml:"ENTRIES,attr,omitempty"`
}

type SortingDataType struct {
	Value *string  `xml:"value,attr,omitempty"`
	Idx   *float64 `xml:"IDX,attr,omitempty"`
	Ord   *float64 `xml:"ORD,attr,omitempty"`
}

type StemsType struct {
	Value *string `xml:"value,attr,omitempty"`
	Stems *string `xml:"STEMS,attr,omitempty"`
}

type SubNodesType struct {
	Node  *NodeType `xml:"NODE,omitempty"`
	Count *float64  `xml:"COUNT,attr,omitempty"`
}

type TempoType struct {
	Value      *string  `xml:"value,attr,omitempty"`
	BPM        *float64 `xml:"BPM,attr,omitempty"`
	BPMQuality *float64 `xml:"BPM_QUALITY,attr,omitempty"`
}

type EntryType struct {
	Location             *LocationType         `xml:"LOCATION,omitempty"`
	Album                *AlbumType            `xml:"ALBUM,omitempty"`
	ModificationInfo     *ModificationInfoType `xml:"MODIFICATION_INFO,omitempty"`
	Info                 *InfoType             `xml:"INFO,omitempty"`
	Tempo                *TempoType            `xml:"TEMPO,omitempty"`
	Loudness             *LoudnessType         `xml:"LOUDNESS,omitempty"`
	MusicalKey           *MusicalKeyType       `xml:"MUSICAL_KEY,omitempty"`
	LoopInfo             *LoopInfoType         `xml:"LOOPINFO,omitempty"`
	CueV2                []CueV2Type           `xml:"CUE_V2,omitempty"`
	Stems                *StemsType            `xml:"STEMS,omitempty"`
	PrimaryKey           *PrimaryKeyType       `xml:"PRIMARYKEY,omitempty"`
	ExtendedData         *ExtendedDataType     `xml:"EXTENDEDDATA,omitempty"`
	ModifiedDate         *string               `xml:"MODIFIED_DATE,attr,omitempty"`
	ModifiedTime         *float64              `xml:"MODIFIED_TIME,attr,omitempty"`
	Lock                 *float64              `xml:"LOCK,attr,omitempty"`
	LockModificationTime *string               `xml:"LOCK_MODIFICATION_TIME,attr,omitempty"`
	AudioID              *string               `xml:"AUDIO_ID,attr,omitempty"`
	Title                *string               `xml:"TITLE,attr,omitempty"`
	Artist               *string               `xml:"ARTIST,attr,omitempty"`
}

type SortingOrderType struct {
	SortingData []SortingDataType `xml:"SORTING_DATA,omitempty"`
	Path        *string           `xml:"PATH,attr,omitempty"`
}

type CollectionType struct {
	Entry   []EntryType `xml:"ENTRY,omitempty"`
	Entries *float64    `xml:"ENTRIES,attr,omitempty"`
}

type PlaylistType struct {
	Entry   []EntryType `xml:"ENTRY,omitempty"`
	Entries *float64    `xml:"ENTRIES,attr,omitempty"`
	Type    *string     `xml:"TYPE,attr,omitempty"`
	UUID    *string     `xml:"UUID,attr,omitempty"`
}

type NodeType struct {
	Playlist *PlaylistType `xml:"PLAYLIST,omitempty"`
	SubNodes *SubNodesType `xml:"SUBNODES,omitempty"`
	Type     *string       `xml:"TYPE,attr,omitempty"`
	Name     *string       `xml:"NAME,attr,omitempty"`
}

type PlaylistsType struct {
	Node *NodeType `xml:"NODE,omitempty"`
}

type NMLType struct {
	Head         *HeadType         `xml:"HEAD,omitempty"`
	MusicFolders *string           `xml:"MUSICFOLDERS,omitempty"`
	Collection   *CollectionType   `xml:"COLLECTION,omitempty"`
	Sets         *SetsType         `xml:"SETS,omitempty"`
	Playlists    *PlaylistsType    `xml:"PLAYLISTS,omitempty"`
	SortingOrder *SortingOrderType `xml:"SORTING_ORDER,omitempty"`
	Version      *float64          `xml:"VERSION,attr,omitempty"`
}

type NML struct {
	NMLType
}
